@@ -4,7 +4,7 @@ from typing import Any, Optional
 
 from beartype import beartype
 
-from flet.control import Control
+from flet.callable_control import CallableControl
 from flet.ref import Ref
 
 
@@ -14,39 +14,27 @@ class ClipboardData:
     d: Optional[str]
 
 
-class Clipboard(Control):
+class Clipboard(CallableControl):
     def __init__(
         self,
         ref: Optional[Ref] = None,
         data: Any = None,
-        #
-        # Specific
-        #
-        value: Optional[str] = None,
     ):
 
-        Control.__init__(
+        CallableControl.__init__(
             self,
             ref=ref,
             data=data,
         )
 
-        self.value = value
-
     def _get_control_name(self):
         return "clipboard"
 
     def _is_isolated(self):
         return True
 
-    # value
-    @property
-    def value(self) -> Optional[str]:
-        return self.__value
+    def set_data(self, data: str):
+        self._call_method("set_data", [data], wait_for_result=False)
 
-    @value.setter
-    @beartype
-    def value(self, value: Optional[str]):
-        self.__value = value
-        cd = ClipboardData(str(time.time()), value)
-        self._set_attr_json("value", cd)
+    def get_data(self) -> str:
+        return self._call_method("get_data", [])
