@@ -4,7 +4,13 @@ from beartype import beartype
 
 from flet.control import Control, OptionalNumber
 from flet.ref import Ref
-from flet.types import AnimationValue, OffsetValue, RotateValue, ScaleValue
+from flet.types import (
+    AnimationValue,
+    OffsetValue,
+    ResponsiveNumber,
+    RotateValue,
+    ScaleValue,
+)
 
 
 class ConstrainedControl(Control):
@@ -12,6 +18,7 @@ class ConstrainedControl(Control):
         self,
         ref: Optional[Ref] = None,
         expand: Union[None, bool, int] = None,
+        col: Optional[ResponsiveNumber] = None,
         opacity: OptionalNumber = None,
         tooltip: Optional[str] = None,
         visible: Optional[bool] = None,
@@ -29,6 +36,7 @@ class ConstrainedControl(Control):
         rotate: RotateValue = None,
         scale: ScaleValue = None,
         offset: OffsetValue = None,
+        aspect_ratio: OptionalNumber = None,
         animate_opacity: AnimationValue = None,
         animate_size: AnimationValue = None,
         animate_position: AnimationValue = None,
@@ -41,6 +49,7 @@ class ConstrainedControl(Control):
             self,
             ref=ref,
             expand=expand,
+            col=col,
             opacity=opacity,
             tooltip=tooltip,
             visible=visible,
@@ -57,6 +66,7 @@ class ConstrainedControl(Control):
         self.scale = scale
         self.rotate = rotate
         self.offset = offset
+        self.aspect_ratio = aspect_ratio
         self.animate_opacity = animate_opacity
         self.animate_size = animate_size
         self.animate_position = animate_position
@@ -66,6 +76,7 @@ class ConstrainedControl(Control):
         self.on_animation_end = on_animation_end
 
     def _before_build_command(self):
+        super()._before_build_command()
         self._set_attr_json("rotate", self.__rotate)
         self._set_attr_json("scale", self.__scale)
         self._set_attr_json("offset", self.__offset)
@@ -169,6 +180,16 @@ class ConstrainedControl(Control):
     def offset(self, value: OffsetValue):
         self.__offset = value
 
+    # aspect_ratio
+    @property
+    def aspect_ratio(self) -> OptionalNumber:
+        return self._get_attr("aspectRatio")
+
+    @aspect_ratio.setter
+    @beartype
+    def aspect_ratio(self, value: OptionalNumber):
+        self._set_attr("aspectRatio", value)
+
     # animate_opacity
     @property
     def animate_opacity(self) -> AnimationValue:
