@@ -5,11 +5,12 @@ from difflib import SequenceMatcher
 from typing import TYPE_CHECKING, Any, Union
 
 from beartype import beartype
-from beartype.typing import List, Optional
+from beartype.typing import Dict, List, Optional
 
 from flet.embed_json_encoder import EmbedJsonEncoder
 from flet.protocol import Command
 from flet.ref import Ref
+from flet.types import ResponsiveNumber
 
 try:
     from typing import Literal
@@ -94,18 +95,21 @@ class Control:
         self,
         ref: Optional[Ref] = None,
         expand: Union[None, bool, int] = None,
+        col: Optional[ResponsiveNumber] = None,
         opacity: OptionalNumber = None,
         tooltip: Optional[str] = None,
         visible: Optional[bool] = None,
         disabled: Optional[bool] = None,
         data: Any = None,
     ):
+        super().__init__()
         self.__page: Optional[Page] = None
         self.__attrs = {}
         self.__previous_children = []
         self._id = None
         self.__uid: Optional[str] = None
         self.expand = expand
+        self.col = col
         self.opacity = opacity
         self.tooltip = tooltip
         self.visible = visible
@@ -124,7 +128,7 @@ class Control:
         pass
 
     def _before_build_command(self):
-        pass
+        self._set_attr_json("col", self._wrap_attr_dict(self.__col))
 
     def did_mount(self):
         pass
@@ -206,6 +210,11 @@ class Control:
             else None
         )
 
+    def _wrap_attr_dict(self, value):
+        if value is None or isinstance(value, Dict):
+            return value
+        return {"": value}
+
     # event_handlers
     @property
     def event_handlers(self):
@@ -252,6 +261,16 @@ class Control:
             value = 1
         self._set_attr("expand", value if value else None)
 
+    # col
+    @property
+    def col(self) -> Optional[ResponsiveNumber]:
+        return self.__col
+
+    @col.setter
+    @beartype
+    def col(self, value: Optional[ResponsiveNumber]):
+        self.__col = value
+
     # opacity
     @property
     def opacity(self):
