@@ -4,7 +4,7 @@ from typing import Optional
 
 try:
     from typing import Literal
-except:
+except ImportError:
     from typing_extensions import Literal
 
 VisualDensity = Literal[
